Attribute<T> class

Implementers

Constructors

Attribute(String key, AttributeScope scope, T value)

Properties

hashCode int
The hash code for this object.
no setteroverride
isBlockExceptHeader bool
no setter
isInline bool
no setter
key String
Unique key of this attribute.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope AttributeScope
final
value → T
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override

Static Properties

align AlignAttribute
final
background BackgroundAttribute
final
blockKeys Set<String>
final
blockKeysExceptHeader Set<String>
final
blockQuote BlockQuoteAttribute
final
bold BoldAttribute
final
centerAlignment Attribute<String?>
no setter
checked Attribute<String?>
no setter
codeBlock CodeBlockAttribute
final
color ColorAttribute
final
exclusiveBlockKeys Set<String>
final
font FontAttribute
final
h1 Attribute<int?>
no setter
h2 Attribute<int?>
no setter
h3 Attribute<int?>
no setter
final
height HeightAttribute
final
indent IndentAttribute
final
indentL1 Attribute<int?>
no setter
indentL2 Attribute<int?>
no setter
indentL3 Attribute<int?>
no setter
inlineCode InlineCodeAttribute
final
inlineKeys Set<String>
final
italic ItalicAttribute
final
justifyAlignment Attribute<String?>
no setter
leftAlignment Attribute<String?>
no setter
final
list ListAttribute
final
ol Attribute<String?>
no setter
placeholder PlaceholderAttribute
final
rightAlignment Attribute<String?>
no setter
script ScriptAttribute
final
size SizeAttribute
final
small SmallAttribute
final
strikeThrough StrikeThroughAttribute
final
style StyleAttribute
final
token TokenAttribute
final
ul Attribute<String?>
no setter
unchecked Attribute<String?>
no setter
underline UnderlineAttribute
final
width WidthAttribute
final

Static Methods

clone(Attribute origin, dynamic value) Attribute
fromKeyValue(String key, dynamic value) Attribute?
getIndentLevel(int? level) Attribute<int?>
getRegistryOrder(Attribute attribute) int

Constants

mobileAlignment → const String
mobileHeight → const String
mobileMargin → const String
mobileWidth → const String