ImageVideoUtils class

Constructors

ImageVideoUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

handleImageButtonTap(BuildContext context, QuillController controller, ImageSource imageSource, OnImagePickCallback onImagePickCallback, {FilePickImpl? filePickImpl, WebImagePickImpl? webImagePickImpl}) Future<void>
For image picking logic
handleVideoButtonTap(BuildContext context, QuillController controller, ImageSource videoSource, OnVideoPickCallback onVideoPickCallback, {FilePickImpl? filePickImpl, WebVideoPickImpl? webVideoPickImpl}) Future<void>
For video picking logic
selectMediaPickSetting(BuildContext context) Future<MediaPickSetting?>