isFirst property
Returns true if this node is the first node in the parent list.
Implementation
bool get isFirst => list!.first == this;
Returns true if this node is the first node in the parent list.
bool get isFirst => list!.first == this;