parent property
Current parent of this node. May be null if this node is not mounted.
Implementation
@override
Line? get parent => super.parent as Line?;
set
parent
(Container<Node?> ? value)
inherited
Current parent of this node. May be null if this node is not mounted.
Implementation
Container? parent;