flutter_quill library
Classes
- AlignAttribute
-
Attribute<
T> - BackgroundAttribute
- BlockEmbed
- There are two built-in embed types supported by Quill documents, however the document model itself does not make any assumptions about the types of embedded objects and allows users to define their own types.
- BlockQuoteAttribute
- BoldAttribute
- CheckboxPoint
- ClearFormatButton
- CodeBlockAttribute
- ColorAttribute
- ColorButton
- Controls color styles.
- DefaultListBlockStyle
- DefaultStyles
- DefaultTextBlockStyle
- Style theme applied to a block of rich text, including single-line paragraphs.
- Delta
- Delta represents a document or a modification of a document as a sequence of insert, delete and retain operations.
- DeltaIterator
- Specialized iterator for Deltas.
- Document
- The rich text document
- EditableContainerParentData
- EditorState
- Base interface for the editor state which defines contract used by various mixins.
- Embed
- An embed node inside of a line in a Quill document.
- Embeddable
- An object which can be embedded into a Quill document.
- FontAttribute
- HeaderAttribute
- HeightAttribute
- HistoryButton
- ImageButton
- ImageVideoUtils
- IndentAttribute
- IndentButton
- InlineCodeAttribute
- InlineCodeStyle
- Theme data for inline code.
- ItalicAttribute
- Leaf
- A leaf in Quill document tree.
- LinkAttribute
- LinkDialog
- LinkDialogState
- LinkStyleButton
- ListAttribute
- Operation
- Operation performed on a rich-text document.
- PlaceholderAttribute
- This is custom attribute for hint
- QuillBulletPoint
- QuillCheckboxBuilder
- QuillController
- QuillDialogTheme
-
QuillDropdownButton<
T> - QuillEditor
- QuillEditorState
- QuillIconButton
- QuillIconTheme
- QuillNumberPoint
- QuillStyles
- QuillToolbar
- QuillVerticalCaretMovementRun
- RenderAbstractEditor
- Base interface for editable render objects.
- RenderEditableContainerBox
- Multi-child render box of editable content.
- RenderEditor
- Displays a document as a vertical list of document segments (lines and blocks).
- ScriptAttribute
- SelectAlignmentButton
- SelectHeaderStyleButton
- SizeAttribute
- SmallAttribute
- StrikeThroughAttribute
- Style
- StyleAttribute
- Text
- A span of formatted text within a line in a Quill document.
- ToggleCheckListButton
- ToggleStyleButton
- TokenAttribute
- UnderlineAttribute
- VideoButton
- WidthAttribute
Enums
- AttributeScope
- ChangeSource
-
Source of a
Change. - LinkMenuAction
- List of possible actions returned from LinkActionPickerDelegate.
- MediaPickSetting
Constants
- kDefaultIconSize → const double
- kIconButtonFactor → const double
Functions
-
defaultToggleStyleButtonBuilder(
BuildContext context, Attribute attribute, IconData icon, Color? fillColor, bool? isToggled, VoidCallback? onPressed, [double iconSize = kDefaultIconSize, QuillIconTheme? iconTheme]) → Widget
Typedefs
- DataDecoder = Object? Function(Object data)
-
Decoder function to convert raw
dataobject into a user-defined data type. - DeleteCallback = void Function(int cursorPosition, bool forward)
-
FilePickImpl
= Future<
String?> Function(BuildContext context) -
LinkActionPickerDelegate
= Future<
LinkMenuAction> Function(BuildContext context, String link) -
MediaPickSettingSelector
= Future<
MediaPickSetting?> Function(BuildContext context) -
OnImagePickCallback
= Future<
String?> Function(File file) -
OnVideoPickCallback
= Future<
String?> Function(File file) - ReplaceTextCallback = bool Function(int index, int len, Object? data)
- TextSelectionChangedHandler = void Function(TextSelection selection, SelectionChangedCause cause)
- Signature for the callback that reports when the user changes the selection (including the cursor location).
- TextSelectionCompletedHandler = void Function()
- Signature for the callback that reports when a selection action is actually completed and ratified. Completion is defined as when the user input has concluded for an entire selection action. For simple taps and keyboard input events that change the selection, this callback is invoked immediately following the TextSelectionChangedHandler. For long taps, the selection is considered complete at the up event of a long tap. For drag selections, the selection completes once the drag/pan event ends or is interrupted.
- ToggleStyleButtonBuilder = Widget Function(BuildContext context, Attribute attribute, IconData icon, Color? fillColor, bool? isToggled, VoidCallback? onPressed, [double iconSize, QuillIconTheme? iconTheme])
-
WebImagePickImpl
= Future<
String?> Function(OnImagePickCallback onImagePickCallback) -
WebVideoPickImpl
= Future<
String?> Function(OnVideoPickCallback onImagePickCallback)