DefaultListBlockStyle class
- Inheritance
-
- Object
- DefaultTextBlockStyle
- DefaultListBlockStyle
Constructors
-
DefaultListBlockStyle(TextStyle style, Tuple2<
double, double> verticalSpacing, Tuple2<double, double> lineSpacing, BoxDecoration? decoration, QuillCheckboxBuilder? checkboxUIBuilder)
Properties
- checkboxUIBuilder → QuillCheckboxBuilder?
-
final
- decoration → BoxDecoration?
-
Decoration of a text block.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
lineSpacing
→ Tuple2<
double, double> -
Vertical spacing for individual lines within a text block.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → TextStyle
-
Base text style for a text block.
finalinherited
-
verticalSpacing
→ Tuple2<
double, double> -
Vertical spacing around a text block.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited